@@ -1540,9 +1540,8 @@ Create a cell measure or field ancillary object.
 #--- End: def
 
 def _ncdimensions(nc, ncvar, g=None):
-    '''
-
-Return a list of the netCDF dimensions corresponding to netCDF variable.
+    '''Return a list of the netCDF dimensions corresponding to netCDF
+variable.
 
 :Parameters:
 
@@ -1563,7 +1562,8 @@ Return a list of the netCDF dimensions corresponding to netCDF variable.
 
 >>> _ncdimensions(nc, 'humidity', g=g)
 ['time', 'lat', 'lon']
-'''
+
+    '''
     ncvariable = nc.variables[ncvar]
 
     ncattrs = ncvariable.ncattrs()
