@@ -9,6 +9,8 @@ from os.path import expandvars as os_path_expandvars
 from os.path import expanduser as os_path_expanduser
 from string  import hexdigits
 
+import re
+
 from numpy import array       as numpy_array
 from numpy import bool_       as numpy_bool_
 from numpy import dtype       as numpy_dtype
@@ -39,6 +41,10 @@ class NetCDFError(Exception):
     '''A runtime netCDF error'''
     pass
 
+class CFWriteError(Exception):
+    '''A CF write error'''
+    pass
+
 def write(fields, filename, fmt='NETCDF4', overwrite=True,
           verbose=False, cfa_options=None, mode='w',
           least_significant_digit=None, endian='native', compress=0,
@@ -323,6 +329,8 @@ and auxiliary coordinate roles for different data variables.
          # -----------------------------------------------------------
          'verbose': verbose,
          '_debug' : _debug,
+
+         'xxx': [],
     }
 
     if fmt == 'CFA3':
@@ -409,10 +417,6 @@ and auxiliary coordinate roles for different data variables.
 
         # Reset HDF chunking
         f.HDF_chunks(org_chunks)
-
-#        if verbose == 1:
-#            for e in f:            
-#                print repr(e)
     #-- End: for
 
     # ---------------------------------------------------------------
@@ -421,28 +425,24 @@ and auxiliary coordinate roles for different data variables.
     g['netcdf'].close()
 #--- End: def
 
-#def _check_name(base, counter, g=None, dimsize=None, cfa=False):
 def _check_name(base, g=None, dimsize=None, cfa=False):
-    '''
+    '''zzz
 
 :Parameters:
 
-    base : str
+    base: `str`
 
-#    counter : int
+    g: `dict`
 
-    g : dict
+    dimsize: `int`, optional
 
-    dimsize : int, optional
-
-    cfa : bool, optional
+    cfa: `bool`, optional
 
 :Returns:
 
-    ncvar : str
+    ncvar: `str`
         NetCDF dimension name or netCDF variable name.
 
-#    counter : int
 
 '''
     ncvar_names = g['ncvar_names']
@@ -452,31 +452,28 @@ def _check_name(base, g=None, dimsize=None, cfa=False):
             if base in ncvar_names and dimsize == g['ncdim_to_size'][base]:
                 # Return the name of an existing netCDF dimension with
                 # this size
-                return base #, counter
+                return base
             
         elif base in g['CFA_ncdims']:
             # Return the name of an existing private CFA-netCDF
             # dimension with this size
-            return base #, counter
+            return base
     #--- End: if
 
+    # Still here?
     if base in ncvar_names:
-
-
         counter = g.setdefault('count_'+base, 1)
     
-    #        ncvar = '%(base)s_%(counter)d' % locals()
         ncvar = '{0}_{1}'.format(base, counter)
         while ncvar in ncvar_names:
             counter += 1
-#            ncvar = '%(base)s_%(counter)d' % locals()
             ncvar = '{0}_{1}'.format(base, counter)
     else:
         ncvar = base
 
     ncvar_names.add(ncvar)
 
-    return ncvar #, counter
+    return ncvar
 #--- End: def
 
 def _write_attributes(netcdf_var, netcdf_attrs):
@@ -1821,12 +1818,16 @@ created. The ``seen`` dictionary is updated for *cfvar*.
 
     '''
     _debug = g['_debug']
-    
+
     if g['verbose']:
         print repr(cfvar)+' netCDF: '+ncvar
 
     if _debug:
         print '        '+repr(cfvar)+' netCDF: '+ncvar
+
+    if not re.match('^\w+$', ncvar):
+        raise CFWriteError('Can\'t create a CF-netCDF variable name for {!r} that contains characters other than letters, digits, and underscores: {}\nSet an appropriate netCDF variable name with the \'ncvar\' attribute'.format(
+            cfvar, ncvar))
         
     # ----------------------------------------------------------------
     # Set the netCDF4.createVariable datatype
@@ -2072,7 +2073,9 @@ def _write_a_field(f, add_to_seen=False, allow_data_expand_dims=True,
         print '    Field:', repr(f)
 
     seen = g['seen']
-      
+
+    xxx = []
+    
     if add_to_seen:
         id_f = id(f)
         org_f = f
@@ -2147,20 +2150,54 @@ def _write_a_field(f, add_to_seen=False, allow_data_expand_dims=True,
                 # include it.
                 f.expand_dims(0, axes=axis, i=True)
                 data_axes.append(axis)
-            #--- End: if
 
             # If the data array (now) spans this axis then create a
             # netCDF dimension for it
             if axis in data_axes:
-                ncdim = getattr(f, 'ncdimensions', {}).get(axis, 'dim')
-                ncdim = _check_name(ncdim, g=g)
 
-                unlimited = _unlimited(f, axis, g=g)
-                _write_dimension(ncdim, f, axis, axis_to_ncdim,
-                                 unlimited=unlimited, g=g)
-             #--- End: if
+                size0 = f.axis_size(axis)
+                
+                items0 = f.items(role=('a', 'm', 'c', 'f'), axes=axis)
+
+                MATCH = False
+                for b1 in g['xxx']:
+                    (ncdim1,  size1),  items1 = b1.items()[0]
+                    if size0 != size1:
+                        continue
+                    
+                    items1 = items1.copy()
+                    for key0, item0 in items0.iteritems():
+                        matched_item = False
+                        for key1, item1 in items1.iteritems():
+                            if item0.equals(item1):
+                                del items1[key1]
+                                matched_item = True
+                                break
+                        #--- End: for        
+
+                        if not matched_item:
+                            break
+                    #--- End: for
+                    
+                    if not items1:
+                        MATCH = True
+                        break
+                #--- End: for
+
+                if MATCH:
+                    ncdim = ncdim1
+                    axis_to_ncdim[axis] = ncdim
+                else:
+                    ncdim = getattr(f, 'ncdimensions', {}).get(axis, 'dim')
+                    ncdim = _check_name(ncdim, g=g)
+
+                    unlimited = _unlimited(f, axis, g=g)
+                    _write_dimension(ncdim, f, axis, axis_to_ncdim,
+                                     unlimited=unlimited, g=g)
+                    
+                    xxx.append({(ncdim, size0): items0})
+            #--- End: if
         #--- End: if
-
     #--- End: for
 
     # ----------------------------------------------------------------
@@ -2173,7 +2210,6 @@ def _write_a_field(f, add_to_seen=False, allow_data_expand_dims=True,
         coordinates = _write_auxiliary_coordinate(f, key, aux_coord,
                                                   coordinates, key_to_ncvar,
                                                   axis_to_ncdim, g=g)
-    #--- End: for
 
     # ----------------------------------------------------------------
     # Create domain ancillaries
@@ -2369,6 +2405,10 @@ def _write_a_field(f, add_to_seen=False, allow_data_expand_dims=True,
         g['seen'][id_f] = {'variable': org_f,
                            'ncvar'   : ncvar,
                            'ncdims'  : ncdimensions}
+
+
+    if xxx:
+        g['xxx'].extend(xxx)
 #--- End: def
 
 def _unlimited(f, axis, g=None):
