@@ -257,19 +257,28 @@ add_unit_alias("10 dB", None, "bel", "bels")
 # --------------------------------------------------------------------
 # Aliases for netCDF4.netcdftime classes
 # --------------------------------------------------------------------
-_netCDF4_netcdftime_utime = netCDF4.netcdftime.utime
-_datetime                 = netCDF4.netcdftime.datetime
-
+if netCDF4.__version__ < '1.4':
+    _netCDF4_netcdftime_utime = netCDF4.netcdftime.utime
+    _datetime                 = netCDF4.netcdftime.datetime
+else:
+    import cftime    
+    _netCDF4_netcdftime_utime = cftime.utime
+    _datetime                 = cftime.datetime
+    
 # --------------------------------------------------------------------
 # Aliases for netCDF4.netcdftime functions
 # --------------------------------------------------------------------
-try:
-    _num2date = netCDF4.num2date
-    _date2num = netCDF4.date2num
-except:
-    _num2date = netCDF4.netcdftime.num2date
-    _date2num = netCDF4.netcdftime.date2num
-
+if netCDF4.__version__ < '1.4':
+    try:
+        _num2date = netCDF4.num2date
+        _date2num = netCDF4.date2num
+    except:
+        _num2date = netCDF4.netcdftime.num2date
+        _date2num = netCDF4.netcdftime.date2num
+else:
+    _num2date = cftime.num2date
+    _date2num = cftime.date2num
+    
 _cached_ut_unit = {}
 _cached_utime   = {}
 
@@ -2304,8 +2313,12 @@ base.
 # Utime object
 #
 # ====================================================================
+if netCDF4.__version__ < '1.4':
+    Parent = netCDF4.netcdftime.utime
+else:
+    Parent = cftime.utime
 
-class Utime(netCDF4.netcdftime.utime):
+class Utime(Parent):
     '''
 
 Performs conversions of netCDF time coordinate data to/from datetime
